@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(
     layout checkerboard scroll
     chess checkers conway sudoku
     calculator calendar banner maze
-    beadwork animate
+    beadwork animate list
 );
 
 use HTML::AutoTag;
@@ -27,6 +27,7 @@ sub south   { generate( @_, theta => -180, tgroups => 0, pinhead => 1 ) }
 sub west    { generate( @_, theta => -270, tgroups => 0 ) }
 
 sub layout          { Spreadsheet::HTML::Presets::layout(           @_ ) }
+sub list            { Spreadsheet::HTML::Presets::List::list(       @_ ) }
 sub handson         { Spreadsheet::HTML::Presets::Handson::handson( @_ ) }
 sub conway          { Spreadsheet::HTML::Presets::Conway::conway(   @_ ) }
 sub calculator      { Spreadsheet::HTML::Presets::Calculator::calculator( @_ ) }
@@ -362,10 +363,10 @@ Object oriented interface:
 
     use Spreadsheet::HTML;
 
-    $generator = Spreadsheet::HTML->new( data => \@data, indent => "\t" );
+    $generator = Spreadsheet::HTML->new( data => \@data, encode => 1 );
 
-    print $generator->portrait;
-    print $generator->landscape( encodes => '<>' );
+    print $generator->portrait( indent => '   ' );
+    print $generator->landscape( indent => "\t" );
 
     $generator = Spreadsheet::HTML->new( file => 'data.xls', worksheet => 2 );
     print $generator->generate( preserve => 1 );
@@ -663,7 +664,7 @@ any configuration to C<headings> or C<-r0> will be discarded.
 
 =item * C<scroll: 0 or 1>
 
-Animate the table cells. See L<Spreadsheet::HTML::Presets::Animate>.
+Scrolls the table cells. See L<Spreadsheet::HTML::Presets::Scroll>.
 
 =item * C<headings>
 
@@ -837,6 +838,8 @@ with little to no additional coding.
 
 =item * C<layout( %params )>
 
+=item * C<list( ordered, col, row, %params )>
+
 =item * C<handson( handsonjs, jquery, css, %params )>
 
 =item * C<banner( on, off, text, font, %params )>
